baseObjects.Extractor

|  | ## Cheshire3 Object Model: Class Extractor

Module baseObjects :: Class Extractor

## Class Extractor
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                           Extractor

Known Subclasses:
  extractor.SimpleExtractor

An Extractor is a processing object called by an Index with the value of an evaluated XPath expression or with a string. Example normalizers might extract keywords from an element or the entire contents thereof as a single string. Extractors must also be used on the query terms to apply the same keyword processing rules, for example.
Instance Methods

process_eventList(self, session, data) Process a list of SAX events serialised in C3 internal format.
process_node(self, session, data) Process a DOM node.
process_string(self, session, data) Process a raw string, eg from an attribute value or the query.
process_xpathResult(self, session, data) Process the result of an XPath expression.
Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### process_eventList(self, session, data) | source code
Process a list of SAX events serialised in C3 internal format.

### process_node(self, session, data) | source code
Process a DOM node.

### process_string(self, session, data) | source code
Process a raw string, eg from an attribute value or the query.

### process_xpathResult(self, session, data) | source code
Process the result of an XPath expression. Convenience function to wrap the other process_* functions and do type checking.